unit View.OrderList;

interface

uses
  System.SysUtils, System.Generics.Collections, System.Classes, JS, Web, WEBLib.Graphics, WEBLib.Controls,
  WEBLib.Forms, WEBLib.Dialogs, WEBLib.Menus, WEBLib.ExtCtrls, WEBLib.StdCtrls,
  WEBLib.JSON, Auth.Service, XData.Web.Client, WebLib.Storage,
  ConnectionModule, App.Types, Vcl.StdCtrls, Vcl.Controls, WEBLib.DBCtrls,
  Data.DB, XData.Web.JsonDataset, XData.Web.Dataset, WEBLib.DB, WEBLib.Grids,
  Vcl.Grids;

type
  TFOrderList = class(TWebForm)
    lblEntries: TWebLabel;
    lblEntries2: TWebLabel;
    edtSearch: TWebEdit;
    pnlMessage: TWebPanel;
    lblMessage: TWebLabel;
    btnCloseNotification: TWebButton;
    XDataWebClient1: TXDataWebClient;
    xdwdsCustomers: TXDataWebDataSet;
    wdsCustomers: TWebDataSource;
    xdwdsCustomersID: TIntegerField;
    xdwdsCustomersNAME: TStringField;
    xdwdsCustomersSHORT_NAME: TStringField;
    xdwdsCustomersADDRESS: TStringField;
    tblOrders: TWebDBTableControl;
    cbCorrugatedPlate: TWebCheckBox;
    cbWebPlate: TWebCheckBox;
    btnConfirm: TWebButton;
    edtCompanyName: TWebEdit;
    edtID: TWebEdit;
    procedure edtIDChange(Sender: TObject);
    procedure edtCompanyNameChange(Sender: TObject);
    procedure tblOrdersClickCell(Sender: TObject; ACol, ARow: Integer);
  private
    [async] procedure GetCustomers;
    procedure FilterDataset;
  public
    class function CreateForm(AElementID: string): TWebForm;
  end;

var
  FOrderList: TFOrderList;

implementation

{$R *.dfm}

{ TFOrderList }

class function TFOrderList.CreateForm(AElementID: string): TWebForm;
begin
  Application.CreateForm(TFOrderList, AElementID, Result,
    procedure(AForm: TObject)
    begin
      with TFOrderList(AForm) do
      begin
        // Initialize or configure form properties as needed
        console.log('TFOrderList created and bound to ElementID:', AElementID);
        GetCustomers;
      end;
    end
  );
end;


procedure TFOrderList.edtCompanyNameChange(Sender: TObject);
begin
//  FilterDataset;
  console.log('Filtering data logic WIP');
end;

procedure TFOrderList.edtIDChange(Sender: TObject);
begin
//  FilterDataset;
  console.log('Filtering data logic WIP');
end;

procedure TFOrderList.GetCustomers;
var
  xdcResponse: TXDataClientResponse;
  ResponseObject: TJSObject;
  DataArray: TJSArray;
begin
  try
    asm
      startSpinner();
    end;
    // Fetch data from the server
    xdcResponse := await(XDataWebClient1.RawInvokeAsync('ILookupService.GetCustomers', []));

    // Log the raw JSON response to verify its structure
    console.log('Raw JSON Response:' + TJSJSON.stringify(xdcResponse.Result));

    // Extract the "data" array from the JSON response
    ResponseObject := TJSObject(xdcResponse.Result);
    DataArray := TJSArray(ResponseObject['data']);

    // Load the extracted array into the dataset
    xdwdsCustomers.Close;
    xdwdsCustomers.SetJsonData(DataArray);
    xdwdsCustomers.Open;

    // Log record count and dataset status
    console.log('Dataset Record Count: ' + IntToStr(xdwdsCustomers.RecordCount));

    if xdwdsCustomers.RecordCount = 0 then
      console.log('Dataset is empty.')
    else
      console.log('Dataset loaded successfully with records.');
  finally
    asm
      setTimeout(endSpinner, 2000);
    end;
  end;
end;



procedure TFOrderList.tblOrdersClickCell(Sender: TObject; ACol, ARow: Integer);
begin
  asm
    startSpinner();
  end;
  try
    // Ensure the dataset is active and the row index is valid
    if xdwdsCustomers.Active and (ARow >= 0) and (ARow < xdwdsCustomers.RecordCount) then
    begin
      xdwdsCustomers.RecNo := ARow + 1; // Set the dataset to the selected row

      // Populate the edit boxes with the dataset field values
      edtCompanyName.Text := xdwdsCustomers.FieldByName('NAME').AsString;
      edtID.Text := xdwdsCustomers.FieldByName('ID').AsString;

      console.log('Row clicked: ARow=' + IntToStr(ARow) + ', Company=' + edtCompanyName.Text + ', ID=' + edtID.Text);
    end;
  finally
    asm
      setTimeout(endSpinner, 2000);
    end;
  end;
end;



procedure TFOrderList.FilterDataset;
var
  FilterTextCompany, FilterTextID: string;
  FilterCondition: string;
begin
  try
    // Get the current filter inputs
    FilterTextCompany := Trim(edtCompanyName.Text);
    FilterTextID := Trim(edtID.Text);

    // Build the filter condition
    FilterCondition := '';
    if FilterTextCompany <> '' then
      FilterCondition := Format('NAME LIKE ''%%%s%%''', [FilterTextCompany]);

    if FilterTextID <> '' then
    begin
      if FilterCondition <> '' then
        FilterCondition := FilterCondition + ' AND ';
      FilterCondition := FilterCondition + Format('ID LIKE ''%%%s%%''', [FilterTextID]);
    end;

    // Apply the filter condition
    xdwdsCustomers.Filtered := False; // Disable existing filter
    xdwdsCustomers.Filter := FilterCondition; // Set new filter
    xdwdsCustomers.Filtered := True; // Enable filtering

    console.log('Filter applied:', FilterCondition);

  except
    on E: Exception do
    begin
      // Handle any errors gracefully
      console.error('Error applying filter:', E.Message);
      ShowMessage('An error occurred while applying the filter. Please check your input.');
    end;
  end;
end;


end.

